/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef ACTION_P_H
#define ACTION_P_H

#include <QAction>
#include <qdeclarative.h>

class Action : public QAction
{

    Q_OBJECT

    Q_PROPERTY(QString icon READ iconSource WRITE setIconSource NOTIFY changed)
    Q_PROPERTY(QString shortcut READ shortcutString WRITE setShortcutString NOTIFY changed)

public:
    explicit Action(QObject *parent = 0);
    ~Action();

    QString iconSource() const;
    void setIconSource(const QString &source);

    QString shortcutString() const;
    void setShortcutString(const QString &shortcut);

private:
    Q_DISABLE_COPY(Action)
};

QML_DECLARE_TYPE(Action)

#endif // ACTION_P_H
